mlpy.learners.native package
============================

.. automodule:: mlpy.learners.native
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   mlpy.learners.native.decision_tree
   mlpy.learners.native.knn
   mlpy.learners.native.linear_regression
   mlpy.learners.native.logistic_regression
   mlpy.learners.native.naive_bayes
